==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/General/converter/translations/converter_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="169"/>
        <source>Track: %1</source>
        <translation>Takelis: %1</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="171"/>
        <source>Preset: %1</source>
        <translation>Šablonas: %1</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="266"/>
        <source>Encoding...</source>
        <translation>Kodavimas...</translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Converter Settings</source>
        <translation>Perkodavimo nustatymai</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="29"/>
        <source>Select tracks to convert:</source>
        <translation>Pasirinkti takelius perkodavimui:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="43"/>
        <source>Output directory:</source>
        <translation>Išsaugojimo aplankas:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="53"/>
        <source>Output file name:</source>
        <translation>Išsaugojamos bylos pavadinimas:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Preset:</source>
        <translation>Šablonas:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="73"/>
        <source>Overwrite existing files</source>
        <translation>Perrašyti esamas bylas</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="90"/>
        <source>Choose a directory</source>
        <translation>Pasirinkite aplanką</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="110"/>
        <source>Artist</source>
        <translation>Atlikėjas</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="111"/>
        <source>Album</source>
        <translation>Albumas</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="112"/>
        <source>Title</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="113"/>
        <source>Track number</source>
        <translation>Takelio numeris</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="114"/>
        <source>Two-digit track number</source>
        <translation>Dviejų skaitmenų takelio numeris</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="115"/>
        <source>Genre</source>
        <translation>Žanras</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="116"/>
        <source>Comment</source>
        <translation>Komentaras</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="117"/>
        <source>Composer</source>
        <translation>Autorius</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="118"/>
        <source>Duration</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="119"/>
        <source>Disc number</source>
        <translation>Disko numeris</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="120"/>
        <source>File name</source>
        <translation>Bylos pavadinimas</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="130"/>
        <source>Create a copy</source>
        <translation>Sukurti kopiją</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="121"/>
        <source>Year</source>
        <translation>Metai</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="122"/>
        <source>Condition</source>
        <translation>Būklė</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="128"/>
        <source>Create</source>
        <translation>Sukurti</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="129"/>
        <source>Edit</source>
        <translation>Taisyti</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="131"/>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="28"/>
        <source>Converter Plugin</source>
        <translation>Perkodavimo įskiepis</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="49"/>
        <source>About Converter Plugin</source>
        <translation>Apie perkodavimo įskiepį</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="50"/>
        <source>Qmmp Converter Plugin</source>
        <translation>Qmmp perkodavimo įskiepis</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation>Šis įskiepis perkoduoja palaikomas audio bylas, naudodamasis išorinėmis perkodavimo programomis</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="35"/>
        <source>Convert</source>
        <translation>Konvertuoti</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="36"/>
        <source>Meta+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="42"/>
        <source>Converting...</source>
        <translation>Konvertuojama...</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Atšaukti</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Šablonų redaktorius</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation>Paggrindiniai</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation>Plėtinys:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation>Komanda</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation>Pasirinkimai</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation>Įrašyti meta duomenis</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation>Konvertuoti į 16 bitų</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation>%1 (Tik skaityti)</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation>Išsaugomas failas</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation>Pasirinkta byla</translation>
    </message>
</context>
</TS>

==> qmmp-0.9.2-1.00.tar.gz: qmmp-0.9.2/src/plugins/General/converter/translations/converter_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="169"/>
        <source>Track: %1</source>
        <translation>Takelis: %1</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="171"/>
        <source>Preset: %1</source>
        <translation>Šablonas: %1</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="266"/>
        <source>Encoding...</source>
        <translation>Kodavimas...</translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Converter Settings</source>
        <translation>Perkodavimo nustatymai</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="29"/>
        <source>Select tracks to convert:</source>
        <translation>Pasirinkti takelius perkodavimui:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="43"/>
        <source>Output directory:</source>
        <translation>Išsaugojimo aplankas:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="53"/>
        <source>Output file name:</source>
        <translation>Išsaugojamos bylos pavadinimas:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Preset:</source>
        <translation>Šablonas:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="73"/>
        <source>Overwrite existing files</source>
        <translation>Perrašyti esamas bylas</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="90"/>
        <source>Choose a directory</source>
        <translation>Pasirinkite aplanką</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="110"/>
        <source>Artist</source>
        <translation>Atlikėjas</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="111"/>
        <source>Album</source>
        <translation>Albumas</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="112"/>
        <source>Album Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="113"/>
        <source>Title</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="114"/>
        <source>Track Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="115"/>
        <source>Two-digit Track Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="120"/>
        <source>Disc Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="121"/>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="122"/>
        <source>File Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="116"/>
        <source>Genre</source>
        <translation>Žanras</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="117"/>
        <source>Comment</source>
        <translation>Komentaras</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="118"/>
        <source>Composer</source>
        <translation>Autorius</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="119"/>
        <source>Duration</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="123"/>
        <source>Year</source>
        <translation>Metai</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="124"/>
        <source>Condition</source>
        <translation>Būklė</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="130"/>
        <source>Create</source>
        <translation>Sukurti</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="131"/>
        <source>Edit</source>
        <translation>Taisyti</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="132"/>
        <source>Create a Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="133"/>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="28"/>
        <source>Converter Plugin</source>
        <translation>Perkodavimo įskiepis</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="49"/>
        <source>About Converter Plugin</source>
        <translation>Apie perkodavimo įskiepį</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="50"/>
        <source>Qmmp Converter Plugin</source>
        <translation>Qmmp perkodavimo įskiepis</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation>Šis įskiepis perkoduoja palaikomas audio bylas, naudodamasis išorinėmis perkodavimo programomis</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="35"/>
        <source>Convert</source>
        <translation>Konvertuoti</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="36"/>
        <source>Meta+C</source>
        <translation>Meta+C</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="42"/>
        <source>Converting...</source>
        <translation>Konvertuojama...</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Atšaukti</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Šablonų redaktorius</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation>Paggrindiniai</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation>Plėtinys:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation>Komanda</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation>Pasirinkimai</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation>Įrašyti meta duomenis</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation>Konvertuoti į 16 bitų</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation>%1 (Tik skaityti)</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation>Išsaugomas failas</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation>Pasirinkta byla</translation>
    </message>
</context>
</TS>
